@@ -87,9 +87,6 @@ volatile gboolean is_available;
 
 extern AgsApplicationContext *ags_application_context;
 
-AgsGuiThread *gui_thread;
-AgsTaskThread *task_thread;
-
 void ags_functional_ffplayer_test_add_test()
 {
   /* add the tests to the suite */
@@ -119,13 +116,6 @@ void ags_functional_ffplayer_test_add_test()
 int
 ags_functional_ffplayer_test_init_suite()
 {
-  /* get gui thread */
-  gui_thread = ags_thread_find_type(ags_application_context->main_loop,
-				    AGS_TYPE_GUI_THREAD);
-
-  task_thread = ags_thread_find_type(ags_application_context->main_loop,
-				     AGS_TYPE_TASK_THREAD);
-    
   return(0);
 }
 
@@ -165,7 +155,7 @@ ags_functional_ffplayer_test_open_sf2()
   /* retrieve ffplayer */
   nth_machine = 0;
 
-  list_start = gtk_container_get_children(xorg_application_context->window->machines);
+  list_start = gtk_container_get_children(AGS_WINDOW(xorg_application_context->window)->machines);
   list = g_list_nth(list_start,
 		    nth_machine);
 
@@ -241,7 +231,7 @@ ags_functional_ffplayer_test_resize_pads()
   /* retrieve ffplayer */
   nth_machine = 0;
 
-  list_start = gtk_container_get_children(xorg_application_context->window->machines);
+  list_start = gtk_container_get_children(AGS_WINDOW(xorg_application_context->window)->machines);
   list = g_list_nth(list_start,
 		    nth_machine);
 
@@ -322,7 +312,7 @@ ags_functional_ffplayer_test_resize_audio_channels()
   /* retrieve ffplayer */
   nth_machine = 0;
 
-  list_start = gtk_container_get_children(xorg_application_context->window->machines);
+  list_start = gtk_container_get_children(AGS_WINDOW(xorg_application_context->window)->machines);
   list = g_list_nth(list_start,
 		    nth_machine);
 
@@ -396,8 +386,7 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, argv,
 				  ags_functional_ffplayer_test_add_test, &is_available);
 
-  pthread_join(ags_functional_test_util_self()[0],
-	       NULL);
+  g_thread_join(ags_functional_test_util_test_runner_thread());
 
   return(-1);
 #else
